(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     17554,        601]
NotebookOptionsPosition[     13094,        473]
NotebookOutlinePosition[     14349,        505]
CellTagsIndexPosition[     14306,        502]
WindowTitle->QuaternionAnalysis - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "GuideColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:guide/Mathematica"],
  FontSlant->"Italic"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell["\<\

\
\>", "GuideText",
 CellID->376297744],

Cell[CellGroupData[{

Cell["QuaternionAnalysis", "GuideTitle",
 CellID->942062912],

Cell[TextData[{
 "\nThe ",
 StyleBox["Quaternion Analysis Package", "InlineCode"],
 " endows the standard package ",
 StyleBox[ButtonBox["Quaternions",
  BaseStyle->"Link",
  ButtonData->"paclet:Quaternions/guide/Quaternions"], "InlineCode"],
 " with the ability to perform operations on quaternion-valued functions and  \
extends its applicability  to arbitrary dimensions."
}], "GuideAbstract",
 CellID->532909609],

Cell[TextData[StyleBox["Objects and other features", "GuideTutorial",
 FontSize->14]], "GuideTutorial",
 CellID->510446030],

Cell[TextData[{
 Cell[TextData[ButtonBox["Quaternion",
  BaseStyle->"Link",
  ButtonData->"paclet:Quaternions/ref/Quaternion"]], "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " represents a quaternion by its numeric or symbolic coefficients "
}], "GuideText",
 CellID->541798723],

Cell[TextData[{
 Cell[TextData[ButtonBox["Paravector",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Paravector"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " represents a paravector by its coefficients"
}], "GuideText",
 CellID->506245113],

Cell[TextData[{
 Cell[TextData[ButtonBox["ComplexLike",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/ComplexLike"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 StyleBox["\[LongDash]", "GuideEmDash"],
 " represents a quaternion or a paravector  by its real part and the norm of \
its vector part. "
}], "GuideText",
 CellID->608686636],

Cell[TextData[{
 Cell[TextData[ButtonBox["SetCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/SetCoordinates"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " sets the coordinates system"
}], "GuideText",
 CellID->33383299],

Cell[TextData[{
 Cell[TextData[ButtonBox["$CoordinatesList",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/$CoordinatesList"]], 
  "InlineFunctionSans"],
 "\[NonBreakingSpace]",
 StyleBox["\[FilledVerySmallSquare]", "InlineSeparator"],
 " ",
 Cell[TextData[ButtonBox["$Dim",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/$Dim"]], "InlineFunctionSans"]
}], "InlineGuideFunctionListing",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->44424217],

Cell["\t", "GuideDelimiter",
 CellID->301547341],

Cell[TextData[StyleBox["Representation forms", "GuideTutorial",
 FontSize->14]], "GuideTutorial",
 CellID->280871178],

Cell[TextData[{
 Cell[TextData[ButtonBox["PolarForm",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/PolarForm"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " polar form of a quaternion/paravector"
}], "GuideText",
 CellID->290862067],

Cell[TextData[{
 Cell[TextData[ButtonBox["QuaternionToComplex",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/QuaternionToComplex"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " complex representation of  a quaternion "
}], "GuideText",
 CellID->139235210],

Cell[TextData[{
 Cell[TextData[ButtonBox["QuaternionToComplexMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/QuaternionToComplexMatrix"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " complex representation matrix of  a quaternion  "
}], "GuideText",
 CellID->75011406],

Cell[TextData[{
 Cell[TextData[ButtonBox["QuaternionToMatrixL",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/QuaternionToMatrixL"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " real left representation matrix of  a quaternion  "
}], "GuideText",
 CellID->8029425],

Cell[TextData[{
 Cell[TextData[ButtonBox["QuaternionToMatrixR",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/QuaternionToMatrixR"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " real right representation matrix of  a quaternion  "
}], "GuideText",
 CellID->202980728],

Cell[TextData[{
 Cell[TextData[ButtonBox["ToComplexLike",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/ToComplexLike"]], 
  "InlineFunctionSans",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " representation of a quaternion/paravector by its numeric or symbolic \
coefficients "
}], "GuideText",
 CellID->58387547],

Cell[TextData[{
 Cell[TextData[ButtonBox["ComplexToQuaternion",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/ComplexToQuaternion"]], 
  "InlineFunctionSans"],
 " "
}], "InlineGuideFunctionListing",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->116426330],

Cell["\t", "GuideDelimiter",
 CellID->264573758],

Cell[TextData[StyleBox["Algebra", "GuideTutorial",
 FontSize->14]], "GuideTutorial",
 CellID->3159975],

Cell[TextData[{
 Cell[TextData[ButtonBox["Abs",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Abs"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extends the absolute value function to quaternion/paravector/complexlike \
objects"
}], "GuideText",
 CellID->38595924],

Cell[TextData[{
 Cell[TextData[ButtonBox["AbsVec",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/AbsVec"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " absolute value of the vector part of an object"
}], "GuideText",
 CellID->203374175],

Cell[TextData[{
 Cell[TextData[ButtonBox["Dot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Dot"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extends the dot product to quaternion objects"
}], "GuideText",
 CellID->111314049],

Cell[TextData[{
 Cell[TextData[ButtonBox["Norm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Norm"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extends the norm function to quaternion/paravector/complexlike objects"
}], "GuideText",
 CellID->28698594],

Cell[TextData[{
 Cell[TextData[ButtonBox["QPower",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/QPower"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " recursive implementation of the function Power"
}], "GuideText",
 CellID->92062707],

Cell[TextData[{
 Cell[TextData[ButtonBox["SymmetricProduct",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/SymmetricProduct"]], 
  "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " gives the symmetric product of two quaternions"
}], "GuideText",
 CellID->1463276848],

Cell[TextData[{
 Cell[TextData[ButtonBox["Vec",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Vec"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " vector part of an object"
}], "GuideText",
 CellID->143246519],

Cell[TextData[{
 Cell[TextData[ButtonBox["W",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/W"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " sign of the vector part of a quaternion/paravector"
}], "GuideText",
 CellID->188243034],

Cell[TextData[{
 Cell[TextData[ButtonBox["PureQuaternionQ",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/PureQuaternionQ"]], 
  "InlineFunctionSans"],
 "\[NonBreakingSpace]",
 StyleBox["\[FilledVerySmallSquare]", "InlineSeparator"],
 " ",
 Cell[TextData[ButtonBox["ScalarQ",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/ScalarQ"]], "InlineFunctionSans"]
}], "InlineGuideFunctionListing",
 CellID->58033752],

Cell["\t", "GuideDelimiter",
 CellID->1998796],

Cell[TextData[StyleBox["Analysis", "GuideTutorial",
 FontSize->14]], "GuideTutorial",
 CellID->106955176],

Cell[TextData[{
 Cell[TextData[ButtonBox["CauchyRiemannL",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/CauchyRiemannL"]], 
  "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["left Cauchy Riemann operator",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->2201459],

Cell[TextData[{
 Cell[TextData[ButtonBox["CauchyRiemannR",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/CauchyRiemannR"]], 
  "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["right Cauchy Riemann operator",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->480101189],

Cell[TextData[{
 Cell[TextData[ButtonBox["DiracL",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/DiracL"]], "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["left Dirac operator",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->161167684],

Cell[TextData[{
 Cell[TextData[ButtonBox["DiracR",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/DiracR"]], "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["right Dirac operator",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->19561035],

Cell[TextData[{
 Cell[TextData[ButtonBox["Laplace",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Laplace"]], "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["Laplace operator",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->132322551],

Cell[TextData[{
 Cell[TextData[ButtonBox["LeftMonogenicQ",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/LeftMonogenicQ"]], 
  "InlineFunctionSans"],
 "\[NonBreakingSpace]",
 StyleBox["\[FilledVerySmallSquare]", "InlineSeparator"],
 " ",
 Cell[TextData[ButtonBox["RightMonogenicQ",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/RightMonogenicQ"]], 
  "InlineFunctionSans"],
 "\[NonBreakingSpace]",
 StyleBox["\[FilledVerySmallSquare]", "InlineSeparator"],
 " ",
 Cell[TextData[ButtonBox["MonogenicQ",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/MonogenicQ"]], 
  "InlineFunctionSans"]
}], "InlineGuideFunctionListing",
 CellID->65059335],

Cell["\t", "GuideDelimiter",
 CellID->466892000],

Cell[TextData[StyleBox["Polynomials", "GuideTutorial",
 FontSize->14]], "GuideTutorial",
 CellID->492897525],

Cell[TextData[{
 Cell[TextData[ButtonBox["Pk",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Pk"]], "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["special monogenic polynomials mimicking the complex powers",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->20481547],

Cell[TextData[{
 Cell[TextData[ButtonBox["Tks",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Tks"]], "InlineFunctionSans"],
 " \[LongDash]",
 StyleBox[" a Pascal-like triangle ",
  FontFamily->"Verdana",
  FontWeight->"Plain"],
 StyleBox["associated with the polinomials Pk",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->909355742],

Cell[TextData[{
 Cell[TextData[ButtonBox["Ck",
  BaseStyle->"Link",
  ButtonData->"paclet:QuaternionAnalysis/ref/Ck"]], "InlineFunctionSans"],
 " \[LongDash] ",
 StyleBox["the alternating sum of Tks",
  FontFamily->"Verdana",
  FontSize->11,
  FontWeight->"Plain"]
}], "InlineGuideFunctionListing",
 CellID->214405451]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIALS", "GuideTutorialsSection",
 CellID->415694126],

Cell[TextData[ButtonBox["Quaternion Analysis Package",
 BaseStyle->"Link",
 ButtonData->
  "paclet:QuaternionAnalysis/tutorial/QuaternionAnalysis"]], "GuideText",
 CellID->296864235],

Cell[TextData[ButtonBox["Quaternions Package",
 BaseStyle->"Link",
 ButtonData->"paclet:Quaternions/tutorial/Quaternions"]], "GuideText",
 CellID->322203887]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"QuaternionAnalysis - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2014, 11, 13, 15, 9, 55.2974812}", "context" -> 
    "QuaternionAnalysis`", "keywords" -> {}, "index" -> True, "label" -> 
    "Quaternion Analysis Guide", "language" -> "en", "paclet" -> 
    "QuaternionAnalysis", "status" -> "None", "summary" -> 
    "The Quaternion Analysis Package endows the standard package Quaternions \
with the ability to perform operations on quaternion-valued functions and \
extends its applicability to arbitrary dimensions.", "synonyms" -> {}, 
    "title" -> "QuaternionAnalysis", "type" -> "Guide", "uri" -> 
    "QuaternionAnalysis/guide/QuaternionAnalysis"}, "LinkTrails" -> "", 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[612, 21, 75, 1, 70, "GuideColorBar"],
Cell[690, 24, 209, 6, 70, "LinkTrail"],
Cell[902, 32, 50, 4, 70, "GuideText",
 CellID->376297744],
Cell[CellGroupData[{
Cell[977, 40, 60, 1, 70, "GuideTitle",
 CellID->942062912],
Cell[1040, 43, 416, 10, 70, "GuideAbstract",
 CellID->532909609],
Cell[1459, 55, 123, 2, 70, "GuideTutorial",
 CellID->510446030],
Cell[1585, 59, 326, 9, 70, "GuideText",
 CellID->541798723],
Cell[1914, 70, 315, 10, 70, "GuideText",
 CellID->506245113],
Cell[2232, 82, 399, 12, 70, "GuideText",
 CellID->608686636],
Cell[2634, 96, 306, 10, 70, "GuideText",
 CellID->33383299],
Cell[2943, 108, 497, 13, 70, "InlineGuideFunctionListing",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->44424217],
Cell[3443, 123, 48, 1, 70, "GuideDelimiter",
 CellID->301547341],
Cell[3494, 126, 117, 2, 70, "GuideTutorial",
 CellID->280871178],
Cell[3614, 130, 307, 10, 70, "GuideText",
 CellID->290862067],
Cell[3924, 142, 330, 10, 70, "GuideText",
 CellID->139235210],
Cell[4257, 154, 349, 10, 70, "GuideText",
 CellID->75011406],
Cell[4609, 166, 338, 10, 70, "GuideText",
 CellID->8029425],
Cell[4950, 178, 341, 10, 70, "GuideText",
 CellID->202980728],
Cell[5294, 190, 361, 11, 70, "GuideText",
 CellID->58387547],
Cell[5658, 203, 291, 8, 70, "InlineGuideFunctionListing",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->116426330],
Cell[5952, 213, 48, 1, 70, "GuideDelimiter",
 CellID->264573758],
Cell[6003, 216, 102, 2, 70, "GuideTutorial",
 CellID->3159975],
Cell[6108, 220, 295, 9, 70, "GuideText",
 CellID->38595924],
Cell[6406, 231, 285, 8, 70, "GuideText",
 CellID->203374175],
Cell[6694, 241, 259, 8, 70, "GuideText",
 CellID->111314049],
Cell[6956, 251, 285, 8, 70, "GuideText",
 CellID->28698594],
Cell[7244, 261, 284, 8, 70, "GuideText",
 CellID->92062707],
Cell[7531, 271, 309, 9, 70, "GuideText",
 CellID->1463276848],
Cell[7843, 282, 257, 8, 70, "GuideText",
 CellID->143246519],
Cell[8103, 292, 279, 8, 70, "GuideText",
 CellID->188243034],
Cell[8385, 302, 448, 12, 70, "InlineGuideFunctionListing",
 CellID->58033752],
Cell[8836, 316, 46, 1, 70, "GuideDelimiter",
 CellID->1998796],
Cell[8885, 319, 105, 2, 70, "GuideTutorial",
 CellID->106955176],
Cell[8993, 323, 345, 11, 70, "InlineGuideFunctionListing",
 CellID->2201459],
Cell[9341, 336, 348, 11, 70, "InlineGuideFunctionListing",
 CellID->480101189],
Cell[9692, 349, 319, 10, 70, "InlineGuideFunctionListing",
 CellID->161167684],
Cell[10014, 361, 319, 10, 70, "InlineGuideFunctionListing",
 CellID->19561035],
Cell[10336, 373, 318, 10, 70, "InlineGuideFunctionListing",
 CellID->132322551],
Cell[10657, 385, 699, 20, 70, "InlineGuideFunctionListing",
 CellID->65059335],
Cell[11359, 407, 48, 1, 70, "GuideDelimiter",
 CellID->466892000],
Cell[11410, 410, 108, 2, 70, "GuideTutorial",
 CellID->492897525],
Cell[11521, 414, 349, 10, 70, "InlineGuideFunctionListing",
 CellID->20481547],
Cell[11873, 426, 414, 13, 70, "InlineGuideFunctionListing",
 CellID->909355742],
Cell[12290, 441, 318, 10, 70, "InlineGuideFunctionListing",
 CellID->214405451]
}, Open  ]],
Cell[CellGroupData[{
Cell[12645, 456, 62, 1, 70, "GuideTutorialsSection",
 CellID->415694126],
Cell[12710, 459, 182, 4, 70, "GuideText",
 CellID->296864235],
Cell[12895, 465, 157, 3, 70, "GuideText",
 CellID->322203887]
}, Open  ]],
Cell[13067, 471, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

