(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     23940,        847]
NotebookOptionsPosition[     18394,        660]
NotebookOutlinePosition[     20031,        707]
CellTagsIndexPosition[     19946,        702]
WindowTitle->MonogenicQ - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["QuaternionAnalysis",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:QuaternionAnalysis/guide/QuaternionAnalysis"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["QUATERNIONANALYSIS PACKAGE PACLET SYMBOL", "PacletNameCell"], Cell[
    TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Quaternion Analysis Package\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/tutorial/QuaternionAnalysis"], \
"\<\"Quaternions Package\"\>":>Documentation`HelpLookup[
       "paclet:Quaternions/tutorial/Quaternions"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"CauchyRiemannL\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/CauchyRiemannL"], "\<\"CauchyRiemannR\"\
\>":>Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/CauchyRiemannR"], "\<\"LeftMonogenicQ\"\
\>":>Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/LeftMonogenicQ"], \
"\<\"RightMonogenicQ\"\>":>Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/RightMonogenicQ"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"QuaternionAnalysis\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/guide/QuaternionAnalysis"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"QuaternionAnalysis/ref/MonogenicQ\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["QuaternionAnalysis/ref/MonogenicQ"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/QuaternionAnalysis/\
ref/MonogenicQ.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "QuaternionAnalysis/ref/MonogenicQ", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell["MonogenicQ", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell["\<\
MonogenicQ[f]\[LineSeparator]gives True if f is monogenic, i.e. \
CauchyRiemannL[f]=CauchyRiemannR[f]=0.\
\>"]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}}],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->269061287],

Cell[TextData[{
 "To use  ",
 StyleBox["MonogenicQ", "InlineCode"],
 ", you first need to load the ",
 StyleBox["Quaternion Analysis Package", "InlineCode"],
 " using ",
 ButtonBox["Needs[\"",
  BaseStyle->"Link",
  ButtonData->"paclet:/ref/Needs"],
 StyleBox["QuaternionAnalysis`\"].", "InlineCode"]
}], "Notes",
 CellID->1067943069],

Cell[TextData[{
 "The function accepts as arguments objects of the form ",
 Cell[BoxData[
  ButtonBox["Quaternion",
   BaseStyle->"Link",
   ButtonData->"paclet:Quaternions/ref/Quaternion"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["Paravector",
   BaseStyle->"Link",
   ButtonData->"paclet:QuaternionAnalysis/ref/Paravector"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["ComplexLike",
   BaseStyle->"Link",
   ButtonData->"paclet:QuaternionAnalysis/ref/ComplexLike"]], "InlineFormula"],
 "."
}], "Notes",
 CellID->302811416]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->270608196],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(4)", "ExampleCount"]
}], "ExampleSection",
 CellID->79091835],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QuaternionAnalysis`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->58310437],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetCoordinates", "::", "valid"}], "MessageName"], ":", 
  " ", "\<\"The coordinates system is set to \[NoBreak]\\!\\({X0, X1, X2, X3}\
\\)\[NoBreak].\"\>"}]], "Message", "MSG",
 CellLabel->"During evaluation of In[1]:=",
 CellID->492496553]
}, Open  ]],

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{"Quaternion", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"X1", " ", "X2", " ", "X3"}], "-", "1"}], ",", 
    RowBox[{"1", "-", 
     RowBox[{"X0", " ", "X2", " ", "X3"}]}], ",", 
    RowBox[{"1", "-", 
     RowBox[{"X0", " ", "X1", " ", "X3"}]}], ",", 
    RowBox[{"1", "-", 
     RowBox[{"X0", " ", "X1", " ", "X2"}]}]}], "]"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"In[2]:=",
 CellID->165240853],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->39826504],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->200441701],

Cell["\<\
In order to use other variables, one need to change the coordinates system\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->339688713],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"In[1]:=",
 CellID->76211],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetCoordinates", "::", "valid"}], "MessageName"], ":", 
  " ", "\<\"The coordinates system is set to \[NoBreak]\\!\\({a, b, c}\\)\
\[NoBreak].\"\>"}]], "Message", "MSG",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"During evaluation of In[1]:=",
 CellID->328970115],

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{"Paravector", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     FractionBox[
      SuperscriptBox["b", "2"], "2"], "-", 
     FractionBox[
      SuperscriptBox["c", "2"], "2"]}], ",", 
    RowBox[{"a", " ", "b"}], ",", 
    RowBox[{"a", " ", "c"}]}], "]"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"In[1]:=",
 CellID->290789610]
}, Open  ]],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->99338716]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->166884395],

Cell["\<\
The default variables for the ComplexLike objects are the first element of \
$CoordinatesList and R\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->174751461],

Cell[CellGroupData[{

Cell[BoxData["$CoordinatesList"], "Input",
 CellLabel->"In[1]:=",
 CellID->29757616],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", ",", "b", ",", "c"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->34379701]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{"ComplexLike", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["R", "2"], "2"]}], "+", 
     SuperscriptBox["a", "2"]}], ",", 
    RowBox[{"R", " ", "a"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->23183173],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->624769235]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->268932846],

Cell["\<\
One can use other variables, as far as they are explicitly mentioned as \
arguments of MonogenicQ\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->286566802],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{"ComplexLike", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["r", "2"], "2"]}], "+", 
     SuperscriptBox["x0", "2"]}], ",", 
    RowBox[{"r", " ", "x0"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->480325590],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->479980466]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{
   RowBox[{"ComplexLike", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["r", "2"], "2"]}], "+", 
      SuperscriptBox["x0", "2"]}], ",", 
     RowBox[{"r", " ", "x0"}]}], "]"}], ",", "x0", ",", "r"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->521551760],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->183998617]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell["\<\
For ComplexLike objects, the use of variables other than X0 and R may require \
additional assumptions\
\>", "Text",
 CellID->113535611],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"Pk", "[", 
   RowBox[{"3", ",", "2", ",", 
    RowBox[{"ComplexLike", "[", 
     RowBox[{"X", ",", "Y"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->130570332],

Cell[BoxData[
 RowBox[{"ComplexLike", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "2"]}], " ", 
     RowBox[{"Im", "[", 
      RowBox[{
       SuperscriptBox["X", "2"], " ", "Y"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"Im", "[", 
       SuperscriptBox["Y", "3"], "]"}]}], "8"], "+", 
    RowBox[{"Re", "[", 
     RowBox[{
      SuperscriptBox["X", "3"], "-", 
      FractionBox[
       RowBox[{"3", " ", "X", " ", 
        SuperscriptBox["Y", "2"]}], "2"]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{
      SuperscriptBox["X", "3"], "-", 
      FractionBox[
       RowBox[{"3", " ", "X", " ", 
        SuperscriptBox["Y", "2"]}], "2"]}], "]"}], "+", 
    RowBox[{
     FractionBox["3", "2"], " ", 
     RowBox[{"Re", "[", 
      RowBox[{
       SuperscriptBox["X", "2"], " ", "Y"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"Re", "[", 
       SuperscriptBox["Y", "3"], "]"}]}], "8"]}]}], "]"}]], "Output",
 ImageSize->{343, 74},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->151076862]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"$Assumptions", "&&", 
    RowBox[{"Y", "\[GreaterEqual]", "0"}], "&&", " ", 
    RowBox[{"X", "\[Element]", "Reals"}]}]}], ";"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->53903885],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"Pk", "[", 
   RowBox[{"3", ",", "2", ",", 
    RowBox[{"ComplexLike", "[", 
     RowBox[{"X", ",", "Y"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->285853846],

Cell[BoxData[
 RowBox[{"ComplexLike", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["X", "3"], "-", 
    FractionBox[
     RowBox[{"3", " ", "X", " ", 
      SuperscriptBox["Y", "2"]}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "8"]}], " ", "Y", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox["X", "2"]}], "+", 
      SuperscriptBox["Y", "2"]}], ")"}]}]}], "]"}]], "Output",
 ImageSize->{273, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->235135756]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MonogenicQ", "[", 
  RowBox[{"%", ",", "X", ",", "Y"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->316617609],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->16033802]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox["CauchyRiemannL",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/CauchyRiemannL"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "   \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["CauchyRiemannR",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/CauchyRiemannR"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["LeftMonogenicQ",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/LeftMonogenicQ"],
   FontFamily->"Verdana"]], "InlineFormula"],
 " \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["RightMonogenicQ",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/RightMonogenicQ"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->108958085]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["Quaternion Analysis Package",
 BaseStyle->"Link",
 ButtonData->
  "paclet:QuaternionAnalysis/tutorial/QuaternionAnalysis"]], "Tutorials",
 CellID->18954368],

Cell[TextData[ButtonBox["Quaternions Package",
 BaseStyle->"Link",
 ButtonData->"paclet:Quaternions/tutorial/Quaternions"]], "Tutorials",
 CellID->920639525]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["QuaternionAnalysis",
 BaseStyle->"Link",
 ButtonData->
  "paclet:QuaternionAnalysis/guide/QuaternionAnalysis"]], "MoreAbout",
 CellID->49650955]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"MonogenicQ - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2014, 11, 13, 15, 10, 23.4090891}", "context" -> 
    "QuaternionAnalysis`", "keywords" -> {}, "index" -> True, "label" -> 
    "QuaternionAnalysis Package Paclet Symbol", "language" -> "en", "paclet" -> 
    "QuaternionAnalysis Package", "status" -> "None", "summary" -> 
    "MonogenicQ[f] gives True if f is monogenic, i.e. \
CauchyRiemannL[f]=CauchyRiemannR[f]=0.", "synonyms" -> {}, "title" -> 
    "MonogenicQ", "type" -> "Symbol", "uri" -> 
    "QuaternionAnalysis/ref/MonogenicQ"}, "LinkTrails" -> "", 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "10.0 for Microsoft Windows (64-bit) (July 1, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[6375, 188, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->270608196]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 19803, 695}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[604, 21, 76, 1, 70, "SymbolColorBar"],
Cell[683, 24, 209, 5, 70, "LinkTrail"],
Cell[895, 31, 3550, 81, 70, "AnchorBarGrid",
 CellID->1],
Cell[4448, 114, 53, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[4526, 119, 305, 9, 70, "Usage"],
Cell[CellGroupData[{
Cell[4856, 132, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->269061287],
Cell[5439, 151, 334, 11, 70, "Notes",
 CellID->1067943069],
Cell[5776, 164, 550, 18, 70, "Notes",
 CellID->302811416]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6375, 188, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->270608196],
Cell[CellGroupData[{
Cell[6861, 205, 147, 5, 70, "ExampleSection",
 CellID->79091835],
Cell[CellGroupData[{
Cell[7033, 214, 126, 3, 70, "Input",
 CellID->58310437],
Cell[7162, 219, 288, 7, 70, "Message",
 CellID->492496553]
}, Open  ]],
Cell[7465, 229, 496, 14, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->165240853],
Cell[7964, 245, 160, 5, 36, "Output",
 CellID->39826504],
Cell[CellGroupData[{
Cell[8149, 254, 125, 3, 70, "ExampleDelimiter",
 CellID->200441701],
Cell[8277, 259, 171, 4, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->339688713],
Cell[CellGroupData[{
Cell[8473, 267, 192, 5, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->76211],
Cell[8668, 274, 334, 8, 70, "Message",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->328970115],
Cell[9005, 284, 446, 14, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->290789610]
}, Open  ]],
Cell[9466, 301, 160, 5, 36, "Output",
 CellID->99338716]
}, Open  ]],
Cell[CellGroupData[{
Cell[9663, 311, 125, 3, 70, "ExampleDelimiter",
 CellID->166884395],
Cell[9791, 316, 196, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->174751461],
Cell[CellGroupData[{
Cell[10012, 325, 84, 2, 70, "Input",
 CellID->29757616],
Cell[10099, 329, 212, 7, 36, "Output",
 CellID->34379701]
}, Open  ]],
Cell[CellGroupData[{
Cell[10348, 341, 319, 11, 70, "Input",
 CellID->23183173],
Cell[10670, 354, 161, 5, 36, "Output",
 CellID->624769235]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10880, 365, 125, 3, 70, "ExampleDelimiter",
 CellID->268932846],
Cell[11008, 370, 194, 5, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->286566802],
Cell[CellGroupData[{
Cell[11227, 379, 322, 11, 70, "Input",
 CellID->480325590],
Cell[11552, 392, 162, 5, 36, "Output",
 CellID->479980466]
}, Open  ]],
Cell[CellGroupData[{
Cell[11751, 402, 364, 12, 70, "Input",
 CellID->521551760],
Cell[12118, 416, 161, 5, 36, "Output",
 CellID->183998617]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12340, 428, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[12574, 437, 146, 4, 70, "Text",
 CellID->113535611],
Cell[CellGroupData[{
Cell[12745, 445, 221, 7, 70, "Input",
 CellID->130570332],
Cell[12969, 454, 1161, 40, 95, "Output",
 CellID->151076862]
}, Open  ]],
Cell[14145, 497, 249, 7, 70, "Input",
 CellID->53903885],
Cell[CellGroupData[{
Cell[14419, 508, 221, 7, 70, "Input",
 CellID->285853846],
Cell[14643, 517, 592, 21, 56, "Output",
 CellID->235135756]
}, Open  ]],
Cell[CellGroupData[{
Cell[15272, 543, 139, 4, 70, "Input",
 CellID->316617609],
Cell[15414, 549, 160, 5, 36, "Output",
 CellID->16033802]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15635, 561, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[16055, 575, 869, 29, 70, "SeeAlso",
 CellID->108958085]
}, Open  ]],
Cell[CellGroupData[{
Cell[16961, 609, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[17383, 623, 181, 4, 70, "Tutorials",
 CellID->18954368],
Cell[17567, 629, 157, 3, 70, "Tutorials",
 CellID->920639525]
}, Open  ]],
Cell[CellGroupData[{
Cell[17761, 637, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[18183, 651, 169, 4, 70, "MoreAbout",
 CellID->49650955]
}, Open  ]],
Cell[18367, 658, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

