(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     20980,        687]
NotebookOptionsPosition[     16278,        539]
NotebookOutlinePosition[     18076,        588]
CellTagsIndexPosition[     17991,        583]
WindowTitle->Paravector - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "SymbolColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 ButtonBox["QuaternionAnalysis",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:QuaternionAnalysis/guide/QuaternionAnalysis"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["QUATERNIONANALYSIS PACLET SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"Tutorials \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"Quaternion Analysis Package\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/tutorial/QuaternionAnalysis"], \
"\<\"Quaternions Package\"\>":>Documentation`HelpLookup[
       "paclet:Quaternions/tutorial/Quaternions"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"See Also \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"SetCoordinates\"\>":>
       Documentation`HelpLookup[
       "paclet:Quaternions/ref/Quaternion"], "\<\"SetCoordinates\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/"], "\<\"SetCoordinates\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/"], "\<\"$CoordinatesList\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/$CoordinatesList"], "\<\"$Dim\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/ref/$Dim"], "\<\"Quaternion\"\>":>
       Documentation`HelpLookup[
       "paclet:Quaternions/ref/Quaternion"], "\<\"ComplexLike\"\>":>
       Documentation`HelpLookup["paclet:QuaternionAnalysis/ref/ComplexLike"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"More About \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"QuaternionAnalysis\"\>":>
       Documentation`HelpLookup[
       "paclet:QuaternionAnalysis/guide/QuaternionAnalysis"]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox["\<\"URL \[RightGuillemet]\"\>",
        StripOnInput->False], {"\<\"QuaternionAnalysis/ref/Paravector\"\>":>
       None, "\<\"Copy Mathematica url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["QuaternionAnalysis/ref/Paravector"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web url\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/QuaternionAnalysis/\
ref/Paravector.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "QuaternionAnalysis/ref/Paravector", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell["Paravector", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       ButtonBox["Paravector",
        BaseStyle->"Link",
        ButtonData->"paclet:QuaternionAnalysis/ref/Paravector"], "[", 
       RowBox[{"x0", ",", "x1", ",", "...", ",", "xn"}], "]"}]], 
      "InlineFormula"],
     " \[LineSeparator]represents the paravector x0 + x1",
     Cell[BoxData[
      FormBox[
       RowBox[{" ", 
        SubscriptBox["e", "1"]}], TraditionalForm]], "InlineMath"],
     " +...+ xn",
     Cell[BoxData[
      FormBox[
       RowBox[{" ", 
        SubscriptBox["e", "n"]}], TraditionalForm]], "InlineMath"],
     ", where ",
     Cell[BoxData[
      FormBox[
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["e", "1"], ",", "\[Ellipsis]", ",", 
         SubscriptBox["e", "n"]}], "}"}], TraditionalForm]], "InlineMath"],
     " is an orthonormal basis of the Euclidean vector space ",
     Cell[BoxData[
      SuperscriptBox["R", "n"]], "InlineFormula"],
     " with a product according to the multiplication rules ",
     Cell[BoxData[
      FormBox[
       RowBox[{
        RowBox[{
         SubscriptBox["e", "k"], " ", 
         SubscriptBox["e", "l"]}], "\[LongEqual]", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["e", "k"]}], " ", 
         SubscriptBox["e", "l"]}]}], TraditionalForm]], "InlineMath"],
     ", if ",
     Cell[BoxData[
      FormBox[
       RowBox[{"k", "\[NotEqual]", "l"}], TraditionalForm]], "InlineMath"],
     " and ",
     Cell[BoxData[
      FormBox[
       RowBox[{
        SubsuperscriptBox["e", "k", "2"], "\[LongEqual]", 
        RowBox[{"-", "1"}]}], TraditionalForm]], "InlineMath"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[
  FrameBox[
   StyleBox[
    RowBox[{"MORE", " ", "INFORMATION"}], "NotesFrameText"],
   StripOnInput->False],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->261243152],

Cell[TextData[{
 "To use ",
 StyleBox["Paravector", "InlineCode"],
 ", you first need to load the ",
 StyleBox["Quaternion Analysis Package", "InlineCode"],
 " using ",
 ButtonBox["Needs[\"",
  BaseStyle->"Link",
  ButtonData->"paclet:/ref/Needs"],
 StyleBox["QuaternionAnalysis`\"]", "InlineCode"]
}], "Notes",
 CellID->59647763]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["EXAMPLES",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->368457784],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection",
 CellID->173801527],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QuaternionAnalysis`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->58310437],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetCoordinates", "::", "valid"}], "MessageName"], ":", 
  " ", "\<\"The coordinates system is set to \[NoBreak]\\!\\({X0, X1, X2, X3}\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:QuaternionAnalysis/ref/SetCoordinates\\\", ButtonNote \
-> \\\"QuaternionAnalysis`SetCoordinates::valid\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellLabel->"During evaluation of In[1]:=",
 CellID->361721245]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["Paravector", "InlineCode"],
 " object:"
}], "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->339688713],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", "5", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"In[2]:=",
 CellID->165240853],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Coordinates", "::", "valid"}], "MessageName"], ":", 
  " ", "\<\"The coordinates system is set to \[NoBreak]\\!\\({X0, X1, X2, X3, \
X4}\\)\[NoBreak].\"\>"}]], "Message", "MSG",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"During evaluation of In[2]:=",
 CellID->257068497],

Cell[BoxData[
 RowBox[{
  RowBox[{"Paravector", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], "//", 
  "TraditionalForm"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellLabel->"In[2]:=",
 CellID->290789610],

Cell[BoxData[
 RowBox[{
  SubscriptBox["e", "0"], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["e", "1"]}], "+", 
  RowBox[{"3", " ", 
   SubscriptBox["e", "2"]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["e", "3"]}], "+", 
  RowBox[{"5", " ", 
   SubscriptBox["e", "4"]}]}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 ImageSize->{161, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->691911220]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->26737718],

Cell[TextData[{
 "Operations on ",
 StyleBox["Paravector", "InlineCode"],
 " objects:"
}], "Text",
 CellID->333246196],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Paravector", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], "+", 
  RowBox[{"2", 
   RowBox[{"Paravector", "[", 
    RowBox[{"5", ",", "4", ",", "3", ",", "2", ",", "1"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[1]:=",
 CellID->60278000],

Cell[BoxData[
 RowBox[{"Paravector", "[", 
  RowBox[{"11", ",", "10", ",", "9", ",", "8", ",", "7"}], "]"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{181, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->49262875],

Cell[BoxData[
 RowBox[{"Conjugate", "[", 
  RowBox[{"Paravector", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], 
  "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellLabel->"In[1]:=",
 CellID->21291902],

Cell[BoxData[
 RowBox[{"Paravector", "[", 
  RowBox[{"1", ",", 
   RowBox[{"-", "2"}], ",", 
   RowBox[{"-", "3"}], ",", 
   RowBox[{"-", "4"}], ",", 
   RowBox[{"-", "5"}]}], "]"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ImageSize->{199, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->433162174]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell[TextData[{
   "Possible Issues",
   "\[NonBreakingSpace]\[NonBreakingSpace]",
   Cell["(1)", "ExampleCount"]
  }], "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1305812373],

Cell["\<\
The product of two paravectors is not, in general, a paravector. Hence, the \
multiplication is not extended for this class of objects.\
\>", "Text",
 CellID->113535611],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Paravector", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], "**", 
  RowBox[{"Paravector", "[", 
   RowBox[{"5", ",", "4", ",", "3", ",", "2", ",", "1"}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->130570332],

Cell[BoxData[
 RowBox[{
  RowBox[{"Paravector", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], "**", 
  RowBox[{"Paravector", "[", 
   RowBox[{"5", ",", "4", ",", "3", ",", "2", ",", "1"}], "]"}]}]], "Output",
 ImageSize->{350, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->87892657]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["SEE ALSO",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "SeeAlsoSection",
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  StyleBox[
   ButtonBox[
    ButtonBox[
     ButtonBox["SetCoordinates",
      BaseStyle->"Link",
      ButtonData->"paclet:Quaternions/ref/Quaternion"],
     BaseStyle->"Link",
     ButtonData->"paclet:QuaternionAnalysis/ref/"],
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "\[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["$CoordinatesList",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/$CoordinatesList"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "  \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["$Dim",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/$Dim"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "  \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["Quaternion",
    BaseStyle->"Link",
    ButtonData->"paclet:Quaternions/ref/Quaternion"],
   FontFamily->"Verdana"]], "InlineFormula"],
 "  \[Bullet] ",
 Cell[BoxData[
  StyleBox[
   ButtonBox["ComplexLike",
    BaseStyle->"Link",
    ButtonData->"paclet:QuaternionAnalysis/ref/ComplexLike"],
   FontFamily->"Verdana"]], "InlineFormula"]
}], "SeeAlso",
 CellID->108958085]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["TUTORIALS",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "TutorialsSection",
 CellID->250839057],

Cell[TextData[ButtonBox["Quaternion Analysis Package",
 BaseStyle->"Link",
 ButtonData->
  "paclet:QuaternionAnalysis/tutorial/QuaternionAnalysis"]], "Tutorials",
 CellID->18954368],

Cell[TextData[ButtonBox["Quaternions Package",
 BaseStyle->"Link",
 ButtonData->"paclet:Quaternions/tutorial/Quaternions"]], "Tutorials",
 CellID->920639525]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["MORE ABOUT",
 BaseStyle->None,
 Appearance->{Automatic, None},
 Evaluator->None,
 Method->"Preemptive",
 ButtonFunction:>(FrontEndExecute[{
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], All, ButtonCell], 
    FrontEndToken["OpenCloseGroup"], 
    FrontEnd`SelectionMove[
     FrontEnd`SelectedNotebook[], After, 
     CellContents]}]& )]], "MoreAboutSection",
 CellID->38303248],

Cell[TextData[ButtonBox["QuaternionAnalysis",
 BaseStyle->"Link",
 ButtonData->
  "paclet:QuaternionAnalysis/guide/QuaternionAnalysis"]], "MoreAbout",
 CellID->404877343]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Paravector - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2014, 11, 13, 15, 10, 26.2392510}", "context" -> 
    "QuaternionAnalysis`", "keywords" -> {}, "index" -> True, "label" -> 
    "QuaternionAnalysis Paclet Symbol", "language" -> "en", "paclet" -> 
    "QuaternionAnalysis", "status" -> "None", "summary" -> 
    "Paravector[x0, x1, ..., xn] represents the paravector x0 + x1 e_1 +...+ \
xn e_n, where {e_1, ..., e_n} is an orthonormal basis of the Euclidean vector \
space R^n with a product according to the multiplication rules e_k e_l == \
-e_k e_l, if k != l and e_k^2 == -1.", "synonyms" -> {}, "title" -> 
    "Paravector", "type" -> "Symbol", "uri" -> 
    "QuaternionAnalysis/ref/Paravector"}, "LinkTrails" -> "", 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> "10.0 for Microsoft Windows (64-bit) (July 1, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[7636, 220, 461, 13, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->368457784]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 17848, 576}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[604, 21, 76, 1, 70, "SymbolColorBar"],
Cell[683, 24, 209, 5, 70, "LinkTrail"],
Cell[895, 31, 3817, 85, 70, "AnchorBarGrid",
 CellID->1],
Cell[4715, 118, 53, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[4793, 123, 1856, 57, 70, "Usage",
 CellID->982511436],
Cell[CellGroupData[{
Cell[6674, 184, 580, 17, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->261243152],
Cell[7257, 203, 330, 11, 70, "Notes",
 CellID->59647763]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7636, 220, 461, 13, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->368457784],
Cell[CellGroupData[{
Cell[8122, 237, 148, 5, 70, "ExampleSection",
 CellID->173801527],
Cell[CellGroupData[{
Cell[8295, 246, 126, 3, 70, "Input",
 CellID->58310437],
Cell[8424, 251, 520, 11, 70, "Message",
 CellID->361721245]
}, Open  ]],
Cell[8959, 265, 160, 6, 70, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->339688713],
Cell[CellGroupData[{
Cell[9144, 275, 163, 4, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->165240853],
Cell[9310, 281, 342, 8, 70, "Message",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->257068497],
Cell[9655, 291, 254, 7, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->290789610],
Cell[9912, 300, 470, 16, 36, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10002.},
 CellID->691911220]
}, Open  ]],
Cell[CellGroupData[{
Cell[10419, 321, 124, 3, 70, "ExampleDelimiter",
 CellID->26737718],
Cell[10546, 326, 118, 5, 70, "Text",
 CellID->333246196],
Cell[CellGroupData[{
Cell[10689, 335, 346, 9, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->60278000],
Cell[11038, 346, 302, 8, 36, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->49262875],
Cell[11343, 356, 251, 7, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->21291902],
Cell[11597, 365, 377, 12, 36, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->433162174]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12035, 384, 231, 7, 70, "ExampleSection",
 CellID->1305812373],
Cell[12269, 393, 179, 4, 70, "Text",
 CellID->113535611],
Cell[CellGroupData[{
Cell[12473, 401, 275, 7, 70, "Input",
 CellID->130570332],
Cell[12751, 410, 363, 10, 36, "Output",
 CellID->87892657]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13175, 427, 417, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[13595, 441, 1212, 42, 70, "SeeAlso",
 CellID->108958085]
}, Open  ]],
Cell[CellGroupData[{
Cell[14844, 488, 419, 12, 70, "TutorialsSection",
 CellID->250839057],
Cell[15266, 502, 181, 4, 70, "Tutorials",
 CellID->18954368],
Cell[15450, 508, 157, 3, 70, "Tutorials",
 CellID->920639525]
}, Open  ]],
Cell[CellGroupData[{
Cell[15644, 516, 419, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[16066, 530, 170, 4, 70, "MoreAbout",
 CellID->404877343]
}, Open  ]],
Cell[16251, 537, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)

